Jira

Struct Jira 

pub struct Jira { /* private fields */ }

Implementations

Source

impl Jira

pub fn get_properties(&self) -> GetPropertyBuilder

Returns an application property or a list of application properties.

let jira = Jira::builder().url("http://jira.example.com")
	.username("user")
	.password("password")
	.build()?;
// Single property
let prop = jira.get_properties()
	.key("jira.home").await?;
// Mutlitple properties
let props = jira.get_properties().await?;
Source

impl Jira

pub fn set_property( &self, id: impl Into<String>, value: impl Into<String>, ) -> SetPropertyBuilder

Modify an application property via PUT. The “value” field present in the PUT will override the existing value.

Source

impl Jira

pub fn get_advanced_settings(&self) -> GetAdvancedSettingsBuilder

Returns the properties that are displayed on the “General Configuration > Advanced Settings” page.

Source

impl Jira

pub fn get_roles(&self) -> GetRolesBuilder

Returns all ApplicationRoles in the system.

Source

impl Jira

pub fn get_role(&self, key: impl Into<String>) -> GetRoleBuilder

Returns the ApplicationRole with the given key if it exists. Returns a 404 if the ApplicationRole is not found.

Source

impl Jira

pub fn update_roles( &self, key: impl Into<String>, ) -> UpdateApplicationRolesBuilder

Updates the ApplicationRoles with the passed data if the version hash is the same as the server. Only the groups and default groups setting of the role may be updated. It is acceptable to pass only the roles that are updated as roles that are present in the server but not in data to update with, will not be deleted.

Note: This currently does the same as Jira::update_role since this accepts 1 role

Source

impl Jira

pub fn update_role( &self, key: impl Into<String>, ) -> UpdateApplicationRoleBuilder

Updates the ApplicationRole with the passed data. Only the groups and default groups setting of the role may be updated.

NOT IMPLEMENTED YET Optional: if versionHash is passed through the If-Match header, the request will be rejected if not the same as the server.

Source

impl Jira

pub fn get_attachment(&self, id: u32) -> GetAttachmentBuilder

Returns the meta-data for an attachment, including the URI of the actual attached file.

Source

impl Jira

pub fn remove_attachment(&self, id: u32) -> RemoveAttachmentBuilder

Remove an attachment from an issue.

Source

impl Jira

pub fn get_attachment_meta(&self) -> GetAttachmentMetaBuilder

Returns the meta information for attachments, specifically if they are enabled and the maximum upload size allowed.

Source

impl Jira

pub fn get_all_system_avatars( &self, avatar_type: impl Into<String>, ) -> GetAllSystemAvatarsBuilder

Returns all system avatars of the given type

Source

impl Jira

pub fn store_temporary_avatar( &self, avatar_type: impl Into<String>, filename: impl Into<String>, size: u64, ) -> StoreTemporaryAvatarBuilder

Creates a temporary avatar and returns cropping instructions

Source

impl Jira

pub fn create_avatar_from_temporary( &self, avatar_type: impl Into<String>, ) -> CreateAvatarFromTemporaryBuilder

Updates the cropping instructions of the temporary avatar.

Source

impl Jira

pub fn get_all_nodes(&self) -> GetAllNodesBuilder

Source

impl Jira

pub fn get_current_index( &self, node_id: impl Into<String>, ) -> GetCurrentIndexBuilder

Request current index from node (the request is processed asynchronously).

Source

impl Jira

pub fn delete_node(&self, node_id: impl Into<String>) -> DeleteNodeBuilder

Delete the node from the cluster if the state of the node is OFFLINE.

Source

impl Jira

pub fn set_node_offline( &self, node_id: impl Into<String>, ) -> SetNodeOfflineBuilder

Change the node’s state to offline if the node is reporting as active, but is not alive.

Don’t use this method as an equivalent of running ./stop-jira.sh. This method doesn’t shut down a node, but only changes its state, so that other nodes don’t communicate with it.

Source

impl Jira

pub fn approve_upgrade(&self) -> ApproveUpgradeBuilder

Source

impl Jira

pub fn cancel_upgrade(&self) -> CancelUpgradeBuilder

Source

impl Jira

pub fn acknowledge_errors(&self) -> AcknowledgeErrorsBuilder

Source

impl Jira

pub fn set_ready_to_upgrade(&self) -> SetReadyToUpgradeBuilder

Source

impl Jira

pub fn get_state(&self) -> GetStateBuilder

Source

impl Jira

pub fn create_component( &self, name: impl Into<String>, project: impl Into<String>, project_id: u64, ) -> CreateComponentBuilder

Create a component.

Source

impl Jira

pub fn update_component(&self, id: u64) -> UpdateComponentBuilder

Modify a component. Any fields present in the request will override existing values. As a convenience, if a field is not present, it is silently ignored.

Note: If lead_user_name is an empty string ("") the component lead will be removed.

Source

impl Jira

pub fn get_component(&self, id: u64) -> GetComponentBuilder

Returns a project component.

Source

impl Jira

pub fn delete_component(&self, id: u64) -> DeleteComponentBuilder

Delete a project component.

Source

impl Jira

Returns counts of issues related to this component.

Source

impl Jira

pub fn get_custom_fields(&self) -> GetCustomFieldsBuilder

Get custom fields

Source

impl Jira

pub fn get_all_fields(&self) -> GetAllFieldsBuilder

Returns a list of all fields, both system and custom

Source

impl Jira

pub fn get_issue(&self, key: impl Into<String>) -> GetIssueBuilder

Returns a full representation of the issue for the given issue key. By default, all fields are returned.

pub fn issue(&self, key: impl Into<String>) -> GetIssueBuilder

Alias for Jira::get_issue

Source

impl Jira

pub fn get_permissions(&self) -> GetPermissionsBuilder

Returns a list of permissions indicating which permissions the user has. Details of the user’s permissions can be obtained in a global, project, issue, or comment context.

Source

impl Jira

pub fn get_all_permissions(&self) -> GetAllPermissionsBuilder

Returns all permissions that are present in the Jira instance

Source

impl Jira