pub struct Jira { /* private fields */ }Implementations
Sourceimpl Jira
impl Jira
Sourcepub fn get_properties(&self) -> GetPropertyBuilder
pub fn get_properties(&self) -> GetPropertyBuilder
Returns an application property or a list of application properties.
let jira = Jira::builder().url("http://jira.example.com")
.username("user")
.password("password")
.build()?;
// Single property
let prop = jira.get_properties()
.key("jira.home").await?;
// Mutlitple properties
let props = jira.get_properties().await?;Sourceimpl Jira
impl Jira
Sourcepub fn get_advanced_settings(&self) -> GetAdvancedSettingsBuilder
pub fn get_advanced_settings(&self) -> GetAdvancedSettingsBuilder
Returns the properties that are displayed on the “General Configuration > Advanced Settings” page.
Sourceimpl Jira
impl Jira
Sourcepub fn update_roles(
&self,
key: impl Into<String>,
) -> UpdateApplicationRolesBuilder
pub fn update_roles( &self, key: impl Into<String>, ) -> UpdateApplicationRolesBuilder
Updates the ApplicationRoles with the passed data if the version hash is the same as the server. Only the groups and default groups setting of the role may be updated. It is acceptable to pass only the roles that are updated as roles that are present in the server but not in data to update with, will not be deleted.
Note: This currently does the same as Jira::update_role since this accepts 1 role
Sourceimpl Jira
impl Jira
Sourcepub fn update_role(
&self,
key: impl Into<String>,
) -> UpdateApplicationRoleBuilder
pub fn update_role( &self, key: impl Into<String>, ) -> UpdateApplicationRoleBuilder
Updates the ApplicationRole with the passed data. Only the groups and default groups setting of the role may be updated.
NOT IMPLEMENTED YET Optional: if versionHash is passed through the If-Match header, the request will be rejected if not the same
as the server.
Sourceimpl Jira
impl Jira
Sourcepub fn get_attachment(&self, id: u32) -> GetAttachmentBuilder
pub fn get_attachment(&self, id: u32) -> GetAttachmentBuilder
Returns the meta-data for an attachment, including the URI of the actual attached file.
Sourceimpl Jira
impl Jira
Sourcepub fn remove_attachment(&self, id: u32) -> RemoveAttachmentBuilder
pub fn remove_attachment(&self, id: u32) -> RemoveAttachmentBuilder
Remove an attachment from an issue.
Sourceimpl Jira
impl Jira
Sourcepub fn get_attachment_meta(&self) -> GetAttachmentMetaBuilder
pub fn get_attachment_meta(&self) -> GetAttachmentMetaBuilder
Returns the meta information for attachments, specifically if they are enabled and the maximum upload size allowed.
Sourceimpl Jira
impl Jira
Sourcepub fn get_all_system_avatars(
&self,
avatar_type: impl Into<String>,
) -> GetAllSystemAvatarsBuilder
pub fn get_all_system_avatars( &self, avatar_type: impl Into<String>, ) -> GetAllSystemAvatarsBuilder
Returns all system avatars of the given type
Sourceimpl Jira
impl Jira
Sourcepub fn create_avatar_from_temporary(
&self,
avatar_type: impl Into<String>,
) -> CreateAvatarFromTemporaryBuilder
pub fn create_avatar_from_temporary( &self, avatar_type: impl Into<String>, ) -> CreateAvatarFromTemporaryBuilder
Updates the cropping instructions of the temporary avatar.
Sourceimpl Jira
impl Jira
pub fn get_all_nodes(&self) -> GetAllNodesBuilder
Sourceimpl Jira
impl Jira
Sourcepub fn get_current_index(
&self,
node_id: impl Into<String>,
) -> GetCurrentIndexBuilder
pub fn get_current_index( &self, node_id: impl Into<String>, ) -> GetCurrentIndexBuilder
Request current index from node (the request is processed asynchronously).
Sourceimpl Jira
impl Jira
Sourcepub fn delete_node(&self, node_id: impl Into<String>) -> DeleteNodeBuilder
pub fn delete_node(&self, node_id: impl Into<String>) -> DeleteNodeBuilder
Delete the node from the cluster if the state of the node is OFFLINE.
Sourceimpl Jira
impl Jira
Sourcepub fn set_node_offline(
&self,
node_id: impl Into<String>,
) -> SetNodeOfflineBuilder
pub fn set_node_offline( &self, node_id: impl Into<String>, ) -> SetNodeOfflineBuilder
Change the node’s state to offline if the node is reporting as active, but is not alive.
Don’t use this method as an equivalent of running ./stop-jira.sh. This method doesn’t shut down a node, but only changes its state, so that other nodes don’t communicate with it.
Sourceimpl Jira
impl Jira
pub fn approve_upgrade(&self) -> ApproveUpgradeBuilder
Sourceimpl Jira
impl Jira
pub fn cancel_upgrade(&self) -> CancelUpgradeBuilder
Sourceimpl Jira
impl Jira
pub fn acknowledge_errors(&self) -> AcknowledgeErrorsBuilder
Sourceimpl Jira
impl Jira
pub fn set_ready_to_upgrade(&self) -> SetReadyToUpgradeBuilder
Sourceimpl Jira
impl Jira
Sourcepub fn update_component(&self, id: u64) -> UpdateComponentBuilder
pub fn update_component(&self, id: u64) -> UpdateComponentBuilder
Modify a component. Any fields present in the request will override existing values. As a convenience, if a field is not present, it is silently ignored.
Note: If lead_user_name is an empty string ("") the component lead will be removed.
Sourceimpl Jira
impl Jira
Sourcepub fn get_component(&self, id: u64) -> GetComponentBuilder
pub fn get_component(&self, id: u64) -> GetComponentBuilder
Returns a project component.
Sourceimpl Jira
impl Jira
Sourcepub fn delete_component(&self, id: u64) -> DeleteComponentBuilder
pub fn delete_component(&self, id: u64) -> DeleteComponentBuilder
Delete a project component.
Sourceimpl Jira
impl Jira
Sourcepub fn get_custom_fields(&self) -> GetCustomFieldsBuilder
pub fn get_custom_fields(&self) -> GetCustomFieldsBuilder
Get custom fields
Sourceimpl Jira
impl Jira
Sourcepub fn get_all_fields(&self) -> GetAllFieldsBuilder
pub fn get_all_fields(&self) -> GetAllFieldsBuilder
Returns a list of all fields, both system and custom
Sourceimpl Jira
impl Jira
Sourcepub fn get_permissions(&self) -> GetPermissionsBuilder
pub fn get_permissions(&self) -> GetPermissionsBuilder
Returns a list of permissions indicating which permissions the user has. Details of the user’s permissions can be obtained in a global, project, issue, or comment context.
Sourceimpl Jira
impl Jira
Sourcepub fn get_all_permissions(&self) -> GetAllPermissionsBuilder
pub fn get_all_permissions(&self) -> GetAllPermissionsBuilder
Returns all permissions that are present in the Jira instance